% Plotting Results
% Original: Anisur Rahman
% Modified By:
%       Jing Wang
%       Sayed Hasan (05/26/2004)
%-------------------------------------------------------------------------
lwpl=2;                       % Plot line width
lwbor=1;                      % Border line width
fsize=18;                     % Font size

string_matrix=[];
for m=1:NV,
    string_matrix = strvcat(string_matrix, ['Vgs = ', num2str(V(m),3)]);
end

% Plotting Id-Vg (linear)
figure(1);
if (NV > 1),
    h1=plot(V,I(2,:)*1e6,'*',V,I(NV,:)*1e6,'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
    set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
    legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 2);
else
    h1=plot(V,I*1e6, 'k');
end
set(h1,'linewidth',[lwpl]);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('I_{DS} [uA]');
set(h1,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc Id_vs_Vgs_lin;

% Plotting Id-Vg (Semilog)
figure(2);
if (NV > 1),
    h1=semilogy(V,I(2,:)*1e6,'*',V,I(NV,:)*1e6,'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
    set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
    legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 2);
else
    h1=semilogy(V,I*1e6, 'k');
end
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('I_{DS} [uA]');
set(h1,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc Id_vs_Vgs_log;

% Plotting Id-Vd
figure(3);
h1 = plot(V, I*1e6);
legend(string_matrix, -1);
%set(gca,'Fontsize',[fsize],'linewidth',[lwbor],'plotboxaspectratio',[2,1,1]);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
set(h1,'linewidth',[lwpl]);
xlabel('V_D [Volt]');
ylabel('I_{DS} [uA]');
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc Id_vs_Vds;

figure(4)
h2 = plot(V, N(2,:)/100,'*', V, N(NV,:)/100,'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('mobile charge/q [#/cm]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 2);
print -dpsc N_vs_Vgs_lin;

figure(5)
h2 = semilogy(V, abs(N(2,:))/100, '*',V, abs(N(NV,:))/100,'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('mobile charge/q [#/cm]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 4);
print -dpsc N_vs_Vgs_log;

figure(6);
h2=plot(V,N/100);
legend(string_matrix, -1);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_D [Volt]');
ylabel('mobile charge/q [#/cm]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc N_vs_Vds;

figure(7);
h2=plot(V,CQ(1,:)/100,'b*', V,CQ(2,:)/100, 'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
%set(gca,'Fontsize',[fsize],'linewidth',[lwbor],'plotboxaspectratio',[2,1,1]);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('quantum capacitance [F/cm]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 4);
print -dpsc CQ_vs_Vgs;

figure(8);
h2=plot(V,v_ave*100);
%set(gca,'Fontsize',[fsize],'linewidth',[lwbor],'plotboxaspectratio',[2,1,1]);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('average velocity [cm/s]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc Velocity_vs_Vgs;

figure(9);
A1=I(2,:); % Id value at low drain voltage
A2=I(NV,:); % Id value at high drain voltage
y1=gradient(log(A1),V);
y2=gradient(log(A2),V);
%%

gm_id_data=ones(2,NV);
gm_id_data(1,:)=y1;
gm_id_data(2,:)=y2;
%h2=plot(V,gm_id_data (1,:),'o', V,gm_id_data (2,:), 'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
h2=plot(V,gm_id_data (2,:), 'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('gm/Id [1/V]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
%legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 4, 'Location','NorthEast');
print -dpsc gm_vs_Vgs;

