% Plotting Results
% Original: Anisur Rahman
% Modified By:
%       Jing Wang
%       Sayed Hasan (05/26/2004)
%-------------------------------------------------------------------------
% Axis label is modified and gm/Id vs Vg is added By:
% Aman Singal and Akira Matsudaira (08/23/2005)
%
lwpl=2;                       % Plot line width
lwbor=1;                      % Border line width
fsize=18;                     % Font size

string_matrix=[];
for b=1:NV,
    string_matrix = strvcat(string_matrix, ['Vgs = ', num2str(V(b),3)]);
end

% Plotting Id-Vg (linear)
figure(1);
if (NV > 1),
    h1=plot(V,I(2,:),'*',V,I(NV,:),'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
    set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
    legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 2);
else
    h1=plot(V,I, 'k');
end
set(h1,'linewidth',[lwpl]);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('I_{DS} [uA/um]');
set(h1,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc Id_vs_Vgs_lin;

% Plotting Id-Vg (Semilog)
figure(2);
if (NV > 1),
    h1=semilogy(V,I(2,:),'*',V,I(NV,:),'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
    set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
    legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 2,'Location','SouthEast');
else
    h1=semilogy(V,I, 'k');
end
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('I_{DS} [uA/um]');
set(h1,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc Id_vs_Vgs_log;

% Plotting Id-Vd
figure(3);
h1 = plot(V, I);
legend(string_matrix, -1);    
%set(gca,'Fontsize',[fsize],'linewidth',[lwbor],'plotboxaspectratio',[2,1,1]);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
set(h1,'linewidth',[lwpl]);
xlabel('V_D [Volt]');
ylabel('I_{DS} [uA/um]');
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc Id_vs_Vds;

figure(4)
h2 = plot(V, N(2,:)./10000,'*', V, N(NV,:)./10000,'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g'); % convert C/m^2 -> #/cm^2
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('mobile charge/q [#/cm^2]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 2);
print -dpsc N_vs_Vgs_lin;

figure(5)
%h2 = semilogy(V, abs(q*N([2,NV],:)));
h2 = semilogy(V, abs(N(2,:)./10000), '*',V, abs(N(NV,:)./10000),'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g'); % convert C/m^2 -> #/cm^2
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('mobile charge/q [#/cm^2]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 4);
print -dpsc N_vs_Vgs_log;

figure(6);
%h2=plot(V,q*N);
h2=plot(V,N./10000); % convert C/m^2 -> #/cm^2
legend(string_matrix, -1);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_D [Volt]');
ylabel('mobile charge/q [#/cm^2]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc N_vs_Vds;

figure(7);
%h2=plot(V,CQ);
CQ
h2=plot(V,CQ(1,:)./10000,'*', V,CQ(2,:)./10000, 'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g'); % convert F/m^2 -> F/cm^2
%set(gca,'Fontsize',[fsize],'linewidth',[lwbor],'plotboxaspectratio',[2,1,1]);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('quantum capacitance [F/cm^2]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 4);
print -dpsc CQ_vs_Vgs;

figure(8);
%h2=plot(V,v_ave);
h2=plot(V,v_ave*100); % convert m/s -> cm/s
%set(gca,'Fontsize',[fsize],'linewidth',[lwbor],'plotboxaspectratio',[2,1,1]);
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('average velocity [cm/s]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
print -dpsc Velocity_vs_Vgs;

% added by Akira Matsudaira 8/23/2005 for gm/ID vs. gate voltage
figure(9);
A1=I(2,:); % Id value at low drain voltage
A2=I(NV,:); % Id value at high drain voltage
y1=gradient(A1,V)./A1; % gm/Id = (d(Id)/d(V))/Id
y2=gradient(A2,V)./A2;
%x1=diff(A1,1)./diff(V,1);x2=diff(A2,1)./diff(V,1);
%for ii=2:length(A1)
 %   A_1(ii-1)=A1(ii);A_2(ii-1)=A2(ii);VV(ii-1)=V(ii);
%end
%y1=x1./A_1;
%y2=x2./A_2;
%gm_id_data=ones(2,NV-1);
gm_id_data=ones(2,NV);
gm_id_data(1,:)=y1;
gm_id_data(2,:)=y2;
h2=plot(V,gm_id_data (1,:),'o', V,gm_id_data (2,:), 'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
%h2=plot(VV,gm_id_data (1,:),'ro', VV,gm_id_data (2,:), 'g-diamond','MarkerEdgeColor','g','MarkerFaceColor','g');
set(gca,'Fontsize',[fsize],'linewidth',[lwbor]);
xlabel('V_G [Volt]');
ylabel('gm/Id [1/V]');
set(h2,'linewidth',[lwpl]);
set(gca,'xlim',[V(1) V(NV)]);
legend(['V_{Ds}=',num2str(V(2),3)],['V_{Ds}=',num2str(V(end),3)], 4, 'Location','NorthEast');
print -dpsc gm_vs_Vgs;