% Save Current Data   added by Aman Singal and Akira Matsudaira 07/17/2005

function [Iout]=treatRs(VGSin,VDSin,IDin, RSD,simflag)

% This function transforms intrinsic I-V for a MOSFET to extrinsic I-V and
% vice versa
% intrinsic-> without series resistance; extrinsic-> with series resistance
%
% INPUTS:
% VGSin : A column vector containing gate biases
% VDSin : A column vector containing drain biases
% IDin  : A matrix of size length(VGSin) X length(VDSin)
% RSD   : Total series resistance, of which half is assigned to source and 
%         rest to drain
% simflag : A string with two possible values-
%               'ext2int'-> The inputs are terminal quantities where series
%               resistances are included and we seek the intrinsic
%               charactristics as Iout
%               Alternatively,
%               'int2ext'--> The inputs are intrinsic quantities and we
%               seek the extrinsic charastristics (with series resistance)
%               as Iout
%
% OUTPUT:
% Iout: A matrix of size length(VGSin) X length(VDSin) with intrinsic or
% extrinsic drain current (depending on simflag). Like IDin, VG changes
% along rows and VD changes along columns.
%
sizeID=size(IDin);
sizeVGS=size(VGSin);
sizeVDS=size(VDSin);
%
if sizeVGS(1)~=sizeID(1)|sizeVDS(1)~=sizeID(2)
    error('IDin does not have correct size')
end
if sizeVGS(2)~=1|sizeVDS(2)~=1
    error('Both VGSin and VDSin must be column vectors')
end

%VGSmat=VGSin*ones(1,sizeID(2))
%VDSmat=VDSin'*ones(sizeID(1),1)
VGStmp=VGSin*ones(1,sizeID(2))
VDStmp=ones(sizeID(1),1)*VDSin'
RS=0.5*RSD;
RD=0.5*RSD;
%

switch simflag
    case 'int2ext'
%        VGStmp=VGSmat-IDin*RS;
%        VDStmp=VDSmat-IDin*(RS+RD);
        VGSmat=VGStmp+IDin*RS*1e-6;
        VDSmat=VDStmp+IDin*(RS+RD)*1e-6;

%        Iout = griddata(VGStmp,VDStmp,IDin,VGSmat,VDSmat);
        sizeof(VGSmat)
	sizeof(VDSmat)
	sizeof(IDin)
	sizeof(VGStmp)
	sizeof(VDStmp)
        Iout = griddata(VGSmat,VDSmat,IDin,VGStmp,VDStmp);
%        figure(20)
%            surf(VGStmp,VDStmp,IDin);
%        figure(21)
%            surf(VGSmat,VDSmat,IDin);
%        figure(22)
%            surf(VGStmp,VDStmp,Iout);
   % keyboard
    case 'ext2int'
        VGSmat=VGStmp+IDin*RS*1e-6;
        VDSmat=VDStmp+IDin*(RS+RD)*1e-6;

%        Iout = griddata(VGStmp,VDStmp,IDin,VGSmat,VDSmat);
        Iout = griddata(VGStmp,VDStmp,IDin,VGSmat,VDSmat);
end
